@@ -15,18 +15,22 @@ from .nedelec import NedelecFirstKind
 class BDM(CiarletElement):
     """Brezzi-Douglas-Marini Hdiv finite element."""
 
-    def __init__(self, reference, order, variant):
+    def __init__(self, reference, order, variant="equispaced"):
         poly = polynomial_set(reference.tdim, reference.tdim, order)
 
         dofs = make_integral_moment_dofs(
             reference,
-            facets=(NormalIntegralMoment, DiscontinuousLagrange, order),
-            cells=(IntegralMoment, NedelecFirstKind, order - 1),
-            variant=variant
+            facets=(NormalIntegralMoment, DiscontinuousLagrange, order, {"variant": variant}),
+            cells=(IntegralMoment, NedelecFirstKind, order - 1, {"variant": variant}),
         )
+        self.variant = variant
 
         super().__init__(reference, order, poly, dofs, reference.tdim, reference.tdim)
 
+    def init_kwargs(self):
+        """Return the kwargs used to create this element."""
+        return {"variant": self.variant}
+
     names = ["Brezzi-Douglas-Marini", "BDM", "N2div"]
     references = ["triangle", "tetrahedron"]
     min_order = 1
