@@ -14,21 +14,30 @@ from .lagrange import DiscontinuousLagrange, SymmetricMatrixDiscontinuousLagrang
 class HellanHerrmannJohnson(CiarletElement):
     """A Hellan-Herrmann-Johnson element."""
 
-    def __init__(self, reference, order, variant):
+    def __init__(self, reference, order, variant="equispaced"):
+        if reference.vertices != reference.reference_vertices:
+            raise NotImplementedError()
         assert reference.name == "triangle"
         poly = [(p[0], p[1], p[1], p[2])
                 for p in polynomial_set(reference.tdim, 3, order)]
 
         dofs = make_integral_moment_dofs(
             reference,
-            facets=(NormalInnerProductIntegralMoment, DiscontinuousLagrange, order),
-            cells=(IntegralMoment, SymmetricMatrixDiscontinuousLagrange, order - 1),
-            variant=variant
+            facets=(NormalInnerProductIntegralMoment, DiscontinuousLagrange, order,
+                    {"variant": variant}),
+            cells=(IntegralMoment, SymmetricMatrixDiscontinuousLagrange, order - 1,
+                   {"variant": variant}),
         )
 
+        self.variant = variant
+
         super().__init__(reference, order, poly, dofs, reference.tdim, reference.tdim ** 2,
                          (reference.tdim, reference.tdim))
 
+    def init_kwargs(self):
+        """Return the kwargs used to create this element."""
+        return {"variant": self.variant}
+
     names = ["Hellan-Herrmann-Johnson", "HHJ"]
     references = ["triangle"]
     min_order = 0
