@@ -15,18 +15,25 @@ from .rt import RaviartThomas
 class NedelecFirstKind(CiarletElement):
     """Nedelec first kind Hcurl finite element."""
 
-    def __init__(self, reference, order, variant):
+    def __init__(self, reference, order, variant="equispaced"):
         poly = polynomial_set(reference.tdim, reference.tdim, order - 1)
         poly += Hcurl_polynomials(reference.tdim, reference.tdim, order)
         dofs = make_integral_moment_dofs(
             reference,
-            edges=(TangentIntegralMoment, DiscontinuousLagrange, order - 1),
-            faces=(IntegralMoment, VectorDiscontinuousLagrange, order - 2, "covariant"),
-            volumes=(IntegralMoment, VectorDiscontinuousLagrange, order - 3, "covariant"),
-            variant=variant
+            edges=(TangentIntegralMoment, DiscontinuousLagrange, order - 1,
+                   {"variant": variant}),
+            faces=(IntegralMoment, VectorDiscontinuousLagrange, order - 2, "covariant",
+                   {"variant": variant}),
+            volumes=(IntegralMoment, VectorDiscontinuousLagrange, order - 3, "covariant",
+                     {"variant": variant}),
         )
 
         super().__init__(reference, order, poly, dofs, reference.tdim, reference.tdim)
+        self.variant = variant
+
+    def init_kwargs(self):
+        """Return the kwargs used to create this element."""
+        return {"variant": self.variant}
 
     names = ["Nedelec", "Nedelec1", "N1curl"]
     references = ["triangle", "tetrahedron"]
@@ -37,18 +44,22 @@ class NedelecFirstKind(CiarletElement):
 class NedelecSecondKind(CiarletElement):
     """Nedelec second kind Hcurl finite element."""
 
-    def __init__(self, reference, order, variant):
+    def __init__(self, reference, order, variant="equispaced"):
         poly = polynomial_set(reference.tdim, reference.tdim, order)
 
         dofs = make_integral_moment_dofs(
             reference,
-            edges=(TangentIntegralMoment, DiscontinuousLagrange, order),
-            faces=(IntegralMoment, RaviartThomas, order - 1, "covariant"),
-            volumes=(IntegralMoment, RaviartThomas, order - 2, "covariant"),
-            variant=variant
+            edges=(TangentIntegralMoment, DiscontinuousLagrange, order, {"variant": variant}),
+            faces=(IntegralMoment, RaviartThomas, order - 1, "covariant", {"variant": variant}),
+            volumes=(IntegralMoment, RaviartThomas, order - 2, "covariant", {"variant": variant}),
         )
 
         super().__init__(reference, order, poly, dofs, reference.tdim, reference.tdim)
+        self.variant = variant
+
+    def init_kwargs(self):
+        """Return the kwargs used to create this element."""
+        return {"variant": self.variant}
 
     names = ["Nedelec2", "N2curl"]
     references = ["triangle", "tetrahedron"]
