@@ -13,7 +13,7 @@ from ..functionals import (PointEvaluation, DotPointEvaluation, IntegralMoment,
 class Q(CiarletElement):
     """A Q element."""
 
-    def __init__(self, reference, order, variant):
+    def __init__(self, reference, order, variant="equispaced"):
         from symfem import create_reference
 
         if order == 0:
@@ -25,13 +25,13 @@ class Q(CiarletElement):
             points, _ = get_quadrature(variant, order + 1)
 
             dofs = []
-            for v_n, v in enumerate(reference.reference_vertices):
+            for v_n, v in enumerate(reference.vertices):
                 dofs.append(PointEvaluation(v, entity=(0, v_n)))
             for edim in range(1, 4):
                 for e_n, vs in enumerate(reference.sub_entities(edim)):
                     entity = create_reference(
                         reference.sub_entity_types[edim],
-                        vertices=tuple(reference.reference_vertices[i] for i in vs))
+                        vertices=tuple(reference.vertices[i] for i in vs))
                     for i in product(range(1, order), repeat=edim):
                         dofs.append(
                             PointEvaluation(
@@ -46,6 +46,11 @@ class Q(CiarletElement):
             dofs,
             reference.tdim,
             1)
+        self.variant = variant
+
+    def init_kwargs(self):
+        """Return the kwargs used to create this element."""
+        return {"variant": self.variant}
 
     names = ["Q", "Lagrange", "P"]
     references = ["quadrilateral", "hexahedron"]
@@ -56,7 +61,7 @@ class Q(CiarletElement):
 class DiscontinuousQ(CiarletElement):
     """A dQ element."""
 
-    def __init__(self, reference, order, variant):
+    def __init__(self, reference, order, variant="equispaced"):
         if order == 0:
             dofs = [
                 PointEvaluation(
@@ -76,6 +81,11 @@ class DiscontinuousQ(CiarletElement):
             dofs,
             reference.tdim,
             1)
+        self.variant = variant
+
+    def init_kwargs(self):
+        """Return the kwargs used to create this element."""
+        return {"variant": self.variant}
 
     names = ["dQ"]
     references = ["quadrilateral", "hexahedron"]
@@ -86,7 +96,7 @@ class DiscontinuousQ(CiarletElement):
 class VectorQ(CiarletElement):
     """A vector Q element."""
 
-    def __init__(self, reference, order, variant):
+    def __init__(self, reference, order, variant="equispaced"):
         scalar_space = Q(reference, order, variant)
         dofs = []
         if reference.tdim == 1:
@@ -107,6 +117,11 @@ class VectorQ(CiarletElement):
             reference.tdim,
             reference.tdim,
         )
+        self.variant = variant
+
+    def init_kwargs(self):
+        """Return the kwargs used to create this element."""
+        return {"variant": self.variant}
 
     names = ["vector Q", "vQ"]
     references = ["quadrilateral", "hexahedron"]
@@ -117,19 +132,23 @@ class VectorQ(CiarletElement):
 class Nedelec(CiarletElement):
     """Nedelec Hcurl finite element."""
 
-    def __init__(self, reference, order, variant):
+    def __init__(self, reference, order, variant="equispaced"):
         poly = quolynomial_set(reference.tdim, reference.tdim, order - 1)
         poly += Hcurl_quolynomials(reference.tdim, reference.tdim, order)
 
         dofs = make_integral_moment_dofs(
             reference,
-            edges=(TangentIntegralMoment, DiscontinuousQ, order - 1),
-            faces=(IntegralMoment, RaviartThomas, order - 1, "covariant"),
-            volumes=(IntegralMoment, RaviartThomas, order - 1, "covariant"),
-            variant=variant
+            edges=(TangentIntegralMoment, DiscontinuousQ, order - 1, {"variant": variant}),
+            faces=(IntegralMoment, RaviartThomas, order - 1, "covariant", {"variant": variant}),
+            volumes=(IntegralMoment, RaviartThomas, order - 1, "covariant", {"variant": variant}),
         )
 
         super().__init__(reference, order, poly, dofs, reference.tdim, reference.tdim)
+        self.variant = variant
+
+    def init_kwargs(self):
+        """Return the kwargs used to create this element."""
+        return {"variant": self.variant}
 
     names = ["NCE", "RTCE", "Qcurl", "Nedelec", "Ncurl"]
     references = ["quadrilateral", "hexahedron"]
@@ -140,18 +159,22 @@ class Nedelec(CiarletElement):
 class RaviartThomas(CiarletElement):
     """Raviart-Thomas Hdiv finite element."""
 
-    def __init__(self, reference, order, variant):
+    def __init__(self, reference, order, variant="equispaced"):
         poly = quolynomial_set(reference.tdim, reference.tdim, order - 1)
         poly += Hdiv_quolynomials(reference.tdim, reference.tdim, order)
 
         dofs = make_integral_moment_dofs(
             reference,
-            facets=(NormalIntegralMoment, DiscontinuousQ, order - 1),
-            cells=(IntegralMoment, Nedelec, order - 1, "contravariant"),
-            variant=variant
+            facets=(NormalIntegralMoment, DiscontinuousQ, order - 1, {"variant": variant}),
+            cells=(IntegralMoment, Nedelec, order - 1, "contravariant", {"variant": variant}),
         )
 
         super().__init__(reference, order, poly, dofs, reference.tdim, reference.tdim)
+        self.variant = variant
+
+    def init_kwargs(self):
+        """Return the kwargs used to create this element."""
+        return {"variant": self.variant}
 
     names = ["NCF", "RTCF", "Qdiv"]
     references = ["quadrilateral", "hexahedron"]
