@@ -15,7 +15,7 @@ from ..functionals import PointInnerProduct
 class Regge(CiarletElement):
     """A Regge element."""
 
-    def __init__(self, reference, order, variant):
+    def __init__(self, reference, order):
         from symfem import create_reference
         assert reference.name in ["triangle", "tetrahedron"]
         if reference.tdim == 2:
@@ -30,7 +30,7 @@ class Regge(CiarletElement):
             for e_n, vs in enumerate(reference.sub_entities(edim)):
                 entity = create_reference(
                     reference.sub_entity_types[edim],
-                    vertices=tuple(reference.reference_vertices[i] for i in vs))
+                    vertices=tuple(reference.vertices[i] for i in vs))
                 for i in product(range(1, order + 2), repeat=edim):
                     if sum(i) < order + 2:
                         for edge in entity.edges[::-1]:
