@@ -1,18 +1,24 @@
 """Reference elements."""
 
 import sympy
-from .symbolic import t, x, subs
+from .symbolic import t, x, subs, sym_sum
 from .vectors import vsub, vnorm, vdot, vcross, vnormalise, vadd
 
 
 class Reference:
-    """A reference element."""
+    """A reference cell on which a finite element can be defined."""
 
     def __init__(self, simplex=False, tp=False):
         self.gdim = len(self.origin)
         self.simplex = simplex
         self.tp = tp
 
+    def get_point(self, reference_coords):
+        """Get a point in the reference from reference coordinates."""
+        assert len(reference_coords) == len(self.axes)
+        return tuple(o + sym_sum(a[i] * b for a, b in zip(self.axes, reference_coords))
+                     for i, o in enumerate(self.origin))
+
     def integral(self, f):
         """Calculate the integral over the element."""
         raise NotImplementedError
@@ -25,6 +31,22 @@ class Reference:
         """Get the inverse map from a cell to the reference."""
         raise NotImplementedError
 
+    def get_map_to_self(self):
+        """Get the map from the canonical reference to this reference."""
+        raise NotImplementedError
+
+    def get_inverse_map_to_self(self):
+        """Get the inverse map from the canonical reference to this reference."""
+        raise NotImplementedError
+
+    def volume(self):
+        """Calculate the volume."""
+        raise NotImplementedError
+
+    def midpoint(self):
+        """Calculate the midpoint."""
+        return tuple(sum(i) * sympy.Integer(1) / len(i) for i in zip(*self.vertices))
+
     def jacobian(self):
         """Calculate the jacobian."""
         assert len(self.axes) == self.tdim
@@ -146,6 +168,18 @@ class Point(Reference):
         assert self.vertices == self.reference_vertices
         return self.vertices
 
+    def get_map_to_self(self):
+        """Get the map from the canonical reference to this reference."""
+        return self.vertices
+
+    def get_inverse_map_to_self(self):
+        """Get the inverse map from the canonical reference to this reference."""
+        return self.reference_vertices
+
+    def volume(self):
+        """Calculate the volume."""
+        return 0
+
 
 class Interval(Reference):
     """An interval."""
@@ -179,6 +213,20 @@ class Interval(Reference):
         v = vsub(vertices[1], vertices[0])
         return (vdot(p, v) / vdot(v, v), )
 
+    def get_map_to_self(self):
+        """Get the map from the canonical reference to this reference."""
+        return tuple(v0 + (v1 - v0) * x[0] for v0, v1 in zip(*self.vertices))
+
+    def get_inverse_map_to_self(self):
+        """Get the inverse map from the canonical reference to this reference."""
+        p = vsub(x, self.vertices[0])
+        v = vsub(self.vertices[1], self.vertices[0])
+        return (vdot(p, v) / vdot(v, v), )
+
+    def volume(self):
+        """Calculate the volume."""
+        return self.jacobian()
+
 
 class Triangle(Reference):
     """A triangle."""
@@ -218,6 +266,29 @@ class Triangle(Reference):
                             [v1[1], v2[1]]]).inv()
         return (vdot(mat.row(0), p), vdot(mat.row(1), p))
 
+    def get_map_to_self(self):
+        """Get the map from the canonical reference to this reference."""
+        return tuple(v0 + (v1 - v0) * x[0] + (v2 - v0) * x[1]
+                     for v0, v1, v2 in zip(*self.vertices))
+
+    def get_inverse_map_to_self(self):
+        """Get the inverse map from the canonical reference to this reference."""
+        if len(self.vertices[0]) == 2:
+            p = vsub(x, self.vertices[0])
+            v1 = vsub(self.vertices[1], self.vertices[0])
+            v2 = vsub(self.vertices[2], self.vertices[0])
+            mat = sympy.Matrix([[v1[0], v2[0]],
+                                [v1[1], v2[1]]]).inv()
+            return (vdot(mat.row(0), p), vdot(mat.row(1), p))
+
+        return tuple(
+            vdot(vsub(x, self.origin), a) / vnorm(a) for a in self.axes
+        )
+
+    def volume(self):
+        """Calculate the volume."""
+        return sympy.Rational(1, 2) * self.jacobian()
+
 
 class Tetrahedron(Reference):
     """A tetrahedron."""
@@ -267,6 +338,26 @@ class Tetrahedron(Reference):
                             [v1[2], v2[2], v3[2]]]).inv()
         return (vdot(mat.row(0), p), vdot(mat.row(1), p), vdot(mat.row(2), p))
 
+    def get_map_to_self(self):
+        """Get the map from the canonical reference to this reference."""
+        return tuple(v0 + (v1 - v0) * x[0] + (v2 - v0) * x[1] + (v3 - v0) * x[2]
+                     for v0, v1, v2, v3 in zip(*self.vertices))
+
+    def get_inverse_map_to_self(self):
+        """Get the inverse map from the canonical reference to this reference."""
+        p = vsub(x, self.vertices[0])
+        v1 = vsub(self.vertices[1], self.vertices[0])
+        v2 = vsub(self.vertices[2], self.vertices[0])
+        v3 = vsub(self.vertices[3], self.vertices[0])
+        mat = sympy.Matrix([[v1[0], v2[0], v3[0]],
+                            [v1[1], v2[1], v3[1]],
+                            [v1[2], v2[2], v3[2]]]).inv()
+        return (vdot(mat.row(0), p), vdot(mat.row(1), p), vdot(mat.row(2), p))
+
+    def volume(self):
+        """Calculate the volume."""
+        return sympy.Rational(1, 6) * self.jacobian()
+
 
 class Quadrilateral(Reference):
     """A quadrilateral."""
@@ -307,6 +398,28 @@ class Quadrilateral(Reference):
                             [v1[1], v2[1]]]).inv()
         return (vdot(mat.row(0), p), vdot(mat.row(1), p))
 
+    def get_map_to_self(self):
+        """Get the map from the canonical reference to this reference."""
+        return tuple(
+            (1 - x[1]) * ((1 - x[0]) * v0 + x[0] * v1) + x[1] * ((1 - x[0]) * v2 + x[0] * v3)
+            for v0, v1, v2, v3 in zip(*self.vertices))
+
+    def get_inverse_map_to_self(self):
+        """Get the inverse map from the canonical reference to this reference."""
+        assert len(self.vertices[0]) == 2
+        assert vadd(self.vertices[0], self.vertices[3]) == vadd(self.vertices[1],
+                                                                self.vertices[2])
+        p = vsub(x, self.vertices[0])
+        v1 = vsub(self.vertices[1], self.vertices[0])
+        v2 = vsub(self.vertices[2], self.vertices[0])
+        mat = sympy.Matrix([[v1[0], v2[0]],
+                            [v1[1], v2[1]]]).inv()
+        return (vdot(mat.row(0), p), vdot(mat.row(1), p))
+
+    def volume(self):
+        """Calculate the volume."""
+        return self.jacobian()
+
 
 class Hexahedron(Reference):
     """A hexahedron."""
@@ -369,6 +482,34 @@ class Hexahedron(Reference):
                             [v1[2], v2[2], v3[2]]]).inv()
         return tuple(vdot(mat.row(i), p) for i in range(mat.rows))
 
+    def get_map_to_self(self):
+        """Get the map from the canonical reference to this reference."""
+        return tuple(
+            (1 - x[2]) * ((1 - x[1]) * ((1 - x[0]) * v0 + x[0] * v1)
+                          + x[1] * ((1 - x[0]) * v2 + x[0] * v3))
+            + x[2] * ((1 - x[1]) * ((1 - x[0]) * v4 + x[0] * v5)
+                      + x[1] * ((1 - x[0]) * v6 + x[0] * v7))
+            for v0, v1, v2, v3, v4, v5, v6, v7 in zip(*self.vertices))
+
+    def get_inverse_map_to_self(self):
+        """Get the inverse map from the canonical reference to this reference."""
+        assert len(self.vertices[0]) == 3
+        for a, b, c, d in self.faces:
+            assert vadd(self.vertices[a], self.vertices[d]) == vadd(self.vertices[b],
+                                                                    self.vertices[c])
+        p = vsub(x, self.vertices[0])
+        v1 = vsub(self.vertices[1], self.vertices[0])
+        v2 = vsub(self.vertices[2], self.vertices[0])
+        v3 = vsub(self.vertices[4], self.vertices[0])
+        mat = sympy.Matrix([[v1[0], v2[0], v3[0]],
+                            [v1[1], v2[1], v3[1]],
+                            [v1[2], v2[2], v3[2]]]).inv()
+        return tuple(vdot(mat.row(i), p) for i in range(mat.rows))
+
+    def volume(self):
+        """Calculate the volume."""
+        return self.jacobian()
+
 
 class Prism(Reference):
     """A (triangular) prism."""
@@ -432,6 +573,32 @@ class Prism(Reference):
                             [v1[2], v2[2], v3[2]]]).inv()
         return tuple(vdot(mat.row(i), p) for i in range(mat.rows))
 
+    def get_map_to_self(self):
+        """Get the map from the canonical reference to this reference."""
+        return tuple(
+            (1 - x[2]) * (v0 + x[0] * (v1 - v0) + x[1] * (v2 - v0))
+            + x[2] * (v3 + x[0] * (v4 - v3) + x[1] * (v5 - v3))
+            for v0, v1, v2, v3, v4, v5 in zip(*self.vertices))
+
+    def get_inverse_map_to_self(self):
+        """Get the inverse map from the canonical reference to this reference."""
+        assert len(self.vertices[0]) == 3
+        for a, b, c, d in self.faces[1:4]:
+            assert vadd(self.vertices[a], self.vertices[d]) == vadd(self.vertices[b],
+                                                                    self.vertices[c])
+        p = vsub(x, self.vertices[0])
+        v1 = vsub(self.vertices[1], self.vertices[0])
+        v2 = vsub(self.vertices[2], self.vertices[0])
+        v3 = vsub(self.vertices[3], self.vertices[0])
+        mat = sympy.Matrix([[v1[0], v2[0], v3[0]],
+                            [v1[1], v2[1], v3[1]],
+                            [v1[2], v2[2], v3[2]]]).inv()
+        return tuple(vdot(mat.row(i), p) for i in range(mat.rows))
+
+    def volume(self):
+        """Calculate the volume."""
+        return sympy.Rational(1, 2) * self.jacobian()
+
 
 class Pyramid(Reference):
     """A (square-based) pyramid."""
@@ -497,6 +664,34 @@ class Pyramid(Reference):
                             [v1[2], v2[2], v3[2]]]).inv()
         return tuple(vdot(mat.row(i), p) for i in range(mat.rows))
 
+    def get_map_to_self(self):
+        """Get the map from the canonical reference to this reference."""
+        return tuple(
+            (1 - x[2]) * (
+                (1 - x[1]) * ((1 - x[0]) * v0 + x[0] * v1)
+                + x[1] * ((1 - x[0]) * v2 + x[0] * v3)
+            ) + x[2] * v4
+            for v0, v1, v2, v3, v4 in zip(*self.vertices))
+
+    def get_inverse_map_to_self(self):
+        """Get the inverse map from the canonical reference to this reference."""
+        assert len(self.vertices[0]) == 3
+        for a, b, c, d in self.faces[:1]:
+            assert vadd(self.vertices[a], self.vertices[d]) == vadd(self.vertices[b],
+                                                                    self.vertices[c])
+        p = vsub(x, self.vertices[0])
+        v1 = vsub(self.vertices[1], self.vertices[0])
+        v2 = vsub(self.vertices[2], self.vertices[0])
+        v3 = vsub(self.vertices[4], self.vertices[0])
+        mat = sympy.Matrix([[v1[0], v2[0], v3[0]],
+                            [v1[1], v2[1], v3[1]],
+                            [v1[2], v2[2], v3[2]]]).inv()
+        return tuple(vdot(mat.row(i), p) for i in range(mat.rows))
+
+    def volume(self):
+        """Calculate the volume."""
+        return sympy.Rational(1, 3) * self.jacobian()
+
 
 class DualPolygon(Reference):
     """A polygon on a barycentric dual grid."""
